@@ -31,6 +31,12 @@ class CreateCorpRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_AlgorithmType(self):
+		return self.get_body_params().get('AlgorithmType')
+
+	def set_AlgorithmType(self,AlgorithmType):
+		self.add_body_params('AlgorithmType', AlgorithmType)
+
 	def get_ParentCorpId(self):
 		return self.get_body_params().get('ParentCorpId')
 
